@@ -25,7 +25,7 @@ class FakeTime(object):
 
     def __call__(self):
         shifted_time = self.time_to_freeze - datetime.timedelta(seconds=time.timezone)
-        return time.mktime(shifted_time.timetuple())
+        return time.mktime(shifted_time.timetuple()) + shifted_time.microsecond / 1000000.0
 
 
 class FakeDateMeta(type):
@@ -34,6 +34,23 @@ class FakeDateMeta(type):
         return isinstance(obj, real_date)
 
 
+def datetime_to_fakedatetime(datetime):
+    return FakeDatetime(datetime.year,
+                        datetime.month,
+                        datetime.day,
+                        datetime.hour,
+                        datetime.minute,
+                        datetime.second,
+                        datetime.microsecond,
+                        datetime.tzinfo)
+
+
+def date_to_fakedate(date):
+    return FakeDate(date.year,
+                    date.month,
+                    date.day)
+
+
 class FakeDate(with_metaclass(FakeDateMeta, real_date)):
     date_to_freeze = None
 
@@ -41,13 +58,13 @@ class FakeDate(with_metaclass(FakeDateMeta, real_date)):
         return real_date.__new__(cls, *args, **kwargs)
 
     def __add__(self, other):
-        result = super(FakeDate, self).__add__(other)
+        result = real_date.__add__(self, other)
         if result is NotImplemented:
             return result
         return date_to_fakedate(result)
 
     def __sub__(self, other):
-        result = super(FakeDate, self).__sub__(other)
+        result = real_date.__sub__(self, other)
         if result is NotImplemented:
             return result
         if isinstance(result, real_date):
@@ -60,6 +77,9 @@ class FakeDate(with_metaclass(FakeDateMeta, real_date)):
         result = cls.date_to_freeze
         return date_to_fakedate(result)
 
+FakeDate.min = date_to_fakedate(real_date.min)
+FakeDate.max = date_to_fakedate(real_date.max)
+
 
 class FakeDatetimeMeta(FakeDateMeta):
     @classmethod
@@ -75,13 +95,13 @@ class FakeDatetime(with_metaclass(FakeDatetimeMeta, real_datetime, FakeDate)):
         return real_datetime.__new__(cls, *args, **kwargs)
 
     def __add__(self, other):
-        result = super(FakeDatetime, self).__add__(other)
+        result = real_datetime.__add__(self, other)
         if result is NotImplemented:
             return result
         return datetime_to_fakedatetime(result)
 
     def __sub__(self, other):
-        result = super(FakeDatetime, self).__sub__(other)
+        result = real_datetime.__sub__(self, other)
         if result is NotImplemented:
             return result
         if isinstance(result, real_datetime):
@@ -102,22 +122,8 @@ class FakeDatetime(with_metaclass(FakeDatetimeMeta, real_datetime, FakeDate)):
         result = cls.time_to_freeze
         return result
 
-
-def datetime_to_fakedatetime(datetime):
-    return FakeDatetime(datetime.year,
-                        datetime.month,
-                        datetime.day,
-                        datetime.hour,
-                        datetime.minute,
-                        datetime.second,
-                        datetime.microsecond,
-                        datetime.tzinfo)
-
-
-def date_to_fakedate(date):
-    return FakeDate(date.year,
-                    date.month,
-                    date.day)
+FakeDatetime.min = datetime_to_fakedatetime(real_datetime.min)
+FakeDatetime.max = datetime_to_fakedatetime(real_datetime.max)
 
 
 class FreezeMixin(object):
@@ -135,7 +141,7 @@ class FreezeMixin(object):
         super(FreezeMixin, self).tearDown()
         self._freezer.stop()
 
-class _freeze_time():
+class _freeze_time(object):
 
     def __init__(self, time_to_freeze_str, tz_offset):
         time_to_freeze = parser.parse(time_to_freeze_str)
@@ -165,11 +171,7 @@ class _freeze_time():
         fake_time = FakeTime(self.time_to_freeze)
         time.time = fake_time
 
-        modules_for_datetime_faking = []
-        modules_for_date_faking = []
-
         modules = sys.modules.values()
-
         for module in modules:
             if module is None:
                 continue
@@ -195,6 +197,8 @@ class _freeze_time():
         time.time = real_time
 
         for mod_name, module in sys.modules.items():
+            if mod_name.startswith('six.moves.'):
+                continue
             if mod_name != 'datetime':
                 if hasattr(module, 'datetime') and module.datetime == FakeDatetime:
                     module.datetime = real_datetime
